@@ -37,6 +37,7 @@ import shutil
 import time
 import contextlib
 import platform
+import threading
 
 WINDOWS_GS64_GLOB = r"C:\Program Files*\gs\gs*\bin\gswin64c.exe"
 WINDOWS_GS32_GLOB = r"C:\Program Files*\gs\gs*\bin\gswin32c.exe"
@@ -111,8 +112,8 @@ def get_directory_location():
     return get_canonical_absolue_expanded_dirname(directory_locator.__file__)
 
 def get_expanded_path(path):
-    """Get the canonical form of the absolute path from a possibly relative path
-    (which may have symlinks, etc.)"""
+    """Expand the user ('~') or any shell variables in the path and return
+    it."""
     return os.path.expandvars(os.path.expanduser(path))
 
 def get_canonical_absolute_expanded_path(path):
@@ -157,12 +158,14 @@ def glob_pathname(path, exact_num_args=False, windows_only=False):
         return [path]
     globbed = glob.glob(path)
     if not globbed: # Empty list of matching paths.
-        print("\nWarning in pdfCropMargins: The wildcards in the path\n   "
-              + path + "\nfailed to expand.  Treating as literal.", file=sys.stderr)
+        #print("\nWarning in pdfCropMargins: Any wildcards in the path\n   "
+        #      + path + "\nfailed to expand; no matching glob.  Treating as "
+        #      "literal.", file=sys.stderr)
         globbed = [path]
     if exact_num_args and len(globbed) != exact_num_args:
-        print("\nError in pdfCropMargins: The wildcards in the path\n   "
-              + path + "\nexpand to the wrong number of files.", file=sys.stderr)
+        print("\nError in pdfCropMargins: The wildcards in the path\n   {}"
+              "\nexpand to the wrong number of files ({} instead of {})."
+              .format(path, len(globbed), exact_num_args), file=sys.stderr)
         cleanup_and_exit(1)
     return globbed
 
@@ -214,7 +217,7 @@ def create_temporary_directory():
     try:
         yield program_temp_directory
     finally:
-        remove_program_temp_directory()
+        uninterrupted_remove_program_temp_directory()
         program_temp_directory = None
         gs_environment["TMPDIR"] = None
 
@@ -237,14 +240,26 @@ def remove_program_temp_directory():
                 print("Cleaning up temp dir...", file=sys.stderr)
                 raise
 
+# This thread is setup outside the function below because an interrupt might
+# occur during the thread's setup time.  Probably overkill, but it doesn't hurt.
+t = threading.Thread(target=remove_program_temp_directory, args=())
+
+def uninterrupted_remove_program_temp_directory():
+    """Call the cleanup function `remove_program_temp_directory` as a thread
+    so it is not halted by interrupts."""
+    global t
+    t.start()
+    t.join()
+    t = threading.Thread(target=remove_program_temp_directory, args=())
+
 def cleanup_and_exit(exit_code, stack_frame=None):
     """Exit the program, after cleaning up the temporary directory.  The `stack_frame`
     argument is for when `signal.signal` calls the function.  The returned `exit_code`
     is the signal number."""
+    uninterrupted_remove_program_temp_directory()
     if stack_frame is not None:
         print("\nThe process of pdf-crop-margins was killed by signal {}..."
                 .format(exit_code), file=sys.stderr)
-    remove_program_temp_directory()
     sys.exit(exit_code)
 
 
